((Drupal, once, Tobii) => {
  function refreshTobii(settings, groups) {
    // Initialize Tobii for lightbox images.
    // eslint-disable-next-line no-unused-vars
    const defaultOptions = {
      selector: '.lightbox-image',
      captionsSelector: 'self',
      captionAttribute: 'data-caption',
      navLabel: [Drupal.t('Previous image'), Drupal.t('Next image')],
      closeLabel: Drupal.t('Close lightbox'),
      dialogTitle: Drupal.t('Lightbox'),
      loadingIndicatorLabel: Drupal.t('Image loading'),
      downloadLabel: Drupal.t('Download image'),
    };
    if (settings.lightbox_tobii) {
      const { zoomText } = settings.lightbox_tobii;
      if (zoomText > '') {
        defaultOptions.zoomText = zoomText;
      }
    }
    groups.forEach((groupElt, groupId) => {
      const options = { ...defaultOptions };
      options.selector = `.lightbox-image[data-group="${groupId}"]`;
      if (groupElt) {
        let lightboxTitle;
        if (groupElt.hasAttribute('data-lightbox-title')) {
          lightboxTitle = groupElt.getAttribute('data-lightbox-title');
        } else if (groupElt.hasAttribute('data-caption')) {
          lightboxTitle = groupElt.getAttribute('data-caption');
        }
        if (lightboxTitle > '') {
          options.dialogTitle = Drupal.t('Lightbox: @caption', {
            '@caption': lightboxTitle,
          });
        }
      }
      return new Tobii(options);
    });
  }

  // Drupal behavior that will initialize tobii on page load and updates.
  Drupal.behaviors.tobii = {
    attach(context, settings) {
      const groups = new Map();
      once(
        'lightbox-tobii-group',
        '[data-lightbox-container]',
        context,
      ).forEach((groupElt) => {
        const groupId = groupElt.getAttribute('data-lightbox-container');
        groupElt.querySelectorAll('a.lightbox-image').forEach((a) => {
          // Find the nearest <figure> element and its <figcaption> child.
          const figcaption = a.closest('figure')?.querySelector('figcaption');
          // Retrieve the 'alt' attribute from the <img> tag inside the <a>.
          const alt = a.querySelector('img')?.getAttribute('alt') || '';
          // Use the <figcaption> content if it exists, fall back to 'alt'.
          const caption = figcaption ? figcaption.textContent.trim() : alt;
          // Set 'data-group' attribute to the value of 'data-lightbox-container'.
          a.setAttribute('data-group', groupId);
          // Set 'data-caption' attribute.
          a.setAttribute('data-caption', caption);
          // If groupElt doesn't have a title, use the image caption as title.
          if (!groupElt.hasAttribute('data-lightbox-title') && caption > '') {
            groupElt.setAttribute('data-lightbox-title', caption);
          }
        });
        // Add the group to the list of groups to refresh.
        groups.set(groupId, groupElt);
      });
      // We now search for all lightbox images not already initialized.
      once(
        'lightbox-tobii-image',
        'a.lightbox-image:not([data-group])',
        context,
      ).forEach((a, index) => {
        // Find the nearest <figure> element and its <figcaption> child.
        const figcaption = a.closest('figure')?.querySelector('figcaption');
        // Retrieve the 'alt' attribute from the <img> tag inside the <a>.
        const alt = a.querySelector('img')?.getAttribute('alt') || '';
        // Use the <figcaption> content if it exists, fall back to 'alt'.
        const caption = figcaption ? figcaption.textContent.trim() : alt;
        // Use existing 'data-lightbox-group' or generate a unique ID.
        const groupId =
          a.getAttribute('data-lightbox-group') ?? `tobii-${index}`;
        // Set 'data-group' attribute to the value of 'data-lightbox-group'.
        a.setAttribute('data-group', groupId);
        // Set 'data-caption' attribute.
        a.setAttribute('data-caption', caption);
        // Add the group to the list of groups to refresh.
        if (!groups.has(groupId)) {
          // Add the first image link as the group element.
          groups.set(groupId, a);
        }
      });
      if (groups.size > 0) {
        refreshTobii(settings, groups);
      }
    },
  };
})(Drupal, once, window.Tobii);
